@@ -1,23 +1,23 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2005, 2006, 2008, 2009 Nicolas Burrus
 # This file is part of Tidydoc.
+# Copyright (C) 2005, 2008, 2009 Nicolas Burrus
 #
-# Tidydoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
 #
-# Tidydoc is distributed in the hope that it will be useful,
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with Foobar; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os, re, sys
+import urllib
 
 from td_tools import *
 import td_config
@@ -56,14 +56,34 @@ def generate_document_index(doctree):
   return html_output
 
 def shorten_string(m):
-  s = m.group(2)
+  s = m.group(1)
   if (len(s) > 48):
     s = s[0:23] + "..." + s[len(s)-1-23:len(s)]
-  return m.group(1) + s + m.group(3)
+  return s + m.group(2)
+
+def process_comments(comments):
+  s = comments
+  s = re.compile(r'^<list>\s*$', re.MULTILINE).sub(
+    "<ul style='padding-left: 1em; text-indent: 0px; margin-left: 0px;'>", 
+    s)
+  s = re.compile(r'^</list>\s*$', re.MULTILINE).sub(
+    "</ul>",
+    s)
+  s = re.compile(r'^\* (.*)$', re.MULTILINE).sub(
+    r'<li>\1</li>', 
+    s)
+  return s
+
+def emptylines_to_br(text):
+  empty_lines = re.compile(r'^\s*?$', re.MULTILINE)
+  return empty_lines.sub("<br>\n", text)
+
+def newlines_to_br(text):
+  return re.sub("\n", "<br>\n", text)
 
 def generate_html_code(doc, dirpath):
   document_tpl = os.path.join(config['templates_path'], 'html/document.tpl')
-  short_filename = re.sub(r'(.*\.)(.*)(\.\w+)$', 
+  short_filename = re.sub(r'(.*)(\.\w+)$', 
                           shorten_string,
                           doc.content['file'][0])
   subs = {
@@ -77,13 +97,12 @@ def generate_html_code(doc, dirpath):
         '%%DOCPATH%%'  : dirpath + '/' + doc.content['file'][0],
         '%%LINK%%'     : config['site_root'] + '/' + dirpath + '/' + doc.content['file'][0],
         '%%LINK_NAME%%' : short_filename,
-        '%%SUMMARY%%'  : re.sub("\n", "<br>\n", doc.content['summary'][0]),
-        '%%COMMENT%%'  : doc.content['comment'][0],
+        '%%SUMMARY%%'  : emptylines_to_br(doc.content['summary'][0]),
+        '%%COMMENT%%'  : emptylines_to_br(process_comments(doc.content['comment'][0])),
         '%%URL%%'      : doc.content['url'][0],
         '%%TITLE%%'    : doc.content['title'][0],
         '%%NBPAGES%%'  : doc.content['nbpages'][0],
-        '%%BIBTEX%%'   : re.sub("\n", "<br>\n",
-                                td_bibtex.generate_bibtex_entry(doc)),
+        '%%BIBTEX%%'   : newlines_to_br(td_bibtex.generate_bibtex_entry(doc)),
         }
   doc_html = replace_in_template(document_tpl, subs)
   return doc_html
@@ -127,6 +146,7 @@ def generate_html_file(doctree, fname):
   subs = {
       '%%DOCS_LIST%%'     : docs_list_html,
       '%%DOCS_INDEX%%'    : docs_index_html,
+      '%%CATEGORY%%'      : urllib.quote(rel_path(doctree.path), ""),
       '%%SUBDIRS_INDEX%%' : subdirs_html,
       '%%SITE_ROOT%%'     : config['site_root'],
       '%%VERSION%%'       : ac_config.version
